@@ -159,6 +159,9 @@ static const NVGetoptOption __options[] = {
     { "eglinfo", 'E', NVGETOPT_HELP_ALWAYS, NULL,
       "Print EGL Information for the X display and exit." },
 
+    { "vulkaninfo", 'k', NVGETOPT_HELP_ALWAYS, NULL,
+      "Print Vulkan Information for the X display and exit." },
+
     { "describe", 'e', NVGETOPT_STRING_ARGUMENT | NVGETOPT_HELP_ALWAYS, NULL,
       "Prints information about a particular attribute.  Specify 'all' to "
       "list the descriptions of all attributes.  Specify 'list' to list the "
